summaryrefslogtreecommitdiff
path: root/src/xmpp/xmpp_stanza.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/xmpp/xmpp_stanza.hpp')
-rw-r--r--src/xmpp/xmpp_stanza.hpp6
1 files changed, 5 insertions, 1 deletions
diff --git a/src/xmpp/xmpp_stanza.hpp b/src/xmpp/xmpp_stanza.hpp
index 53e0139..a34ef50 100644
--- a/src/xmpp/xmpp_stanza.hpp
+++ b/src/xmpp/xmpp_stanza.hpp
@@ -86,10 +86,14 @@ public:
*/
std::string get_tail() const;
/**
* Get a pointer to the first child element with that name
*/
XmlNode* get_child(const std::string& name, const std::string& xmlns) const;
/**
+ * Get a vector of all the children that have that name and that xml namespace.
+ */
+ std::vector<XmlNode*> get_children(const std::string& name, const std::string& xmlns) const;
+ /**
* Add a node child to this node. Assign this node to the child’s parent.
* Returns a pointer to the newly added child.
*/
@@ -86,10 +86,14 @@ public:
std::string get_tail() const;
/**
- * Get a pointer to the first child element with that name
+ * Get a pointer to the first child element with that name and that xml namespace
*/
XmlNode* get_child(const std::string& name, const std::string& xmlns) const;